`TIMEX` (referred as `timexseries` in code) is a Python package which implements a pipeline for time-series forecasting.

The pipeline consists in:

- time-series data ingestion;
- time-series pre-processing; 
- time-series analysis and prediction;
- results visualization.

While `TIMEX` is intended to be use in a fully automatic way (which means that each
step is automatically computed, without user intervention), users can also take
advantage of single parts of the framework.

Documentation is still a work in progress.

## Get started
Refer to the Examples section of the GitHub repository, or check the 
[source code](https://github.com/AlexMV12/covid-timex.it) of 
[covid-timex.it](https://covid-timex.it).

